* Stata 15 code to compare actual and potential refugee flows
* Michael Clemens, February 5, 2019
version 15
clear all

* Replace 'XXX' with path to working directory
cd "XXX"

import delimited "RSQDepartures_all_origin.csv", varnames(1) rowrange(13) 
rename extracted year
destring year, replace force
rename v6 countryofresettlementiso
rename v8 totaldeparturespersons
destring totaldeparturespersons, force replace
gen us = countryofresettlementiso=="USA"
collapse (sum) totaldeparturespersons, by(us year)
drop if year==.
reshape wide totaldeparturespersons, i(year) j(us)
keep if year>=2008
tsset year
gen ddep0 = d.totaldeparturespersons0
gen ddep1 = d.totaldeparturespersons1
reg ddep1 ddep0, nocons
predict dcounter
gen counter1 = totaldeparturespersons1[_n-1]+dcounter if year==2017
replace counter1 = counter1[_n-1]+dcounter if year==2018
replace counter1 = totaldeparturespersons1 if year==2016

graph twoway line totaldeparturespersons0 year, c(l) lcolor(emerald) lwidth(medthick) /// 
	|| line totaldeparturespersons1 year, c(l) lcolor(cranberry) lwidth(medthick) ///
	|| line counter1 year if year>=2016, c(l) lcolor(cranberry%50) lwidth(medthick) lpattern(shortdash) ylabel(0(20000)80000, format(%7.0fc)) ///
	scheme(s1color) plotregion(lcolor(none) margin(zero)) ytitle("Arrivals of resettled refugees", margin(medium)) ///
	legend(rows(3) label(1 "Non-USA") label(2 "USA actual") label(3 "USA hypothetical") region(lstyle(none) margin(none))) ///
	xline(2016.5, lcolor(gs8) lwidth(thin)) text(83000 2016.475 "New US admin.", color(gs8) size(small) placement(east)) ///
	xtick(2008(1)2018) xtitle("Year", margin(medsmall)) graphregion(margin(large))

graph export refugees.png, width(1600) replace
	
gen diff = counter1- totaldeparturespersons1
gen pct =  totaldeparturespersons1/counter1
gen worlddep = totaldeparturespersons0+ totaldeparturespersons1
gen counterworlddep = totaldeparturespersons0+ counter1
gen worldpct = worlddep/ counterworlddep
	
